<?php return array(
    'root' => array(
        'name' => 'ldap-account-manager/ldap-account-manager',
        'pretty_version' => '8.7',
        'version' => '8.7.0.0',
        'reference' => null,
        'type' => 'library',
        'install_path' => __DIR__ . '/../../../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        'beberlei/assert' => array(
            'pretty_version' => 'v3.3.2',
            'version' => '3.3.2.0',
            'reference' => 'cb70015c04be1baee6f5f5c953703347c0ac1655',
            'type' => 'library',
            'install_path' => __DIR__ . '/../beberlei/assert',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'brick/math' => array(
            'pretty_version' => '0.9.3',
            'version' => '0.9.3.0',
            'reference' => 'ca57d18f028f84f777b2168cd1911b0dee2343ae',
            'type' => 'library',
            'install_path' => __DIR__ . '/../brick/math',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'carbonphp/carbon-doctrine-types' => array(
            'pretty_version' => '2.1.0',
            'version' => '2.1.0.0',
            'reference' => '99f76ffa36cce3b70a4a6abce41dba15ca2e84cb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../carbonphp/carbon-doctrine-types',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'christian-riesen/base32' => array(
            'pretty_version' => '1.6.0',
            'version' => '1.6.0.0',
            'reference' => '2e82dab3baa008e24a505649b0d583c31d31e894',
            'type' => 'library',
            'install_path' => __DIR__ . '/../christian-riesen/base32',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/inflector' => array(
            'pretty_version' => '2.0.10',
            'version' => '2.0.10.0',
            'reference' => '5817d0659c5b50c9b950feb9af7b9668e2c436bc',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/inflector',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'duosecurity/duo_universal_php' => array(
            'pretty_version' => '1.0.2',
            'version' => '1.0.2.0',
            'reference' => '8734a47480d2d2f0539e8ee782675e052025d026',
            'type' => 'library',
            'install_path' => __DIR__ . '/../duosecurity/duo_universal_php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'facile-it/php-jose-verifier' => array(
            'pretty_version' => '0.3.0',
            'version' => '0.3.0.0',
            'reference' => 'b6a3d17896dec0c3e383c0ae83b7be855b8fd247',
            'type' => 'library',
            'install_path' => __DIR__ . '/../facile-it/php-jose-verifier',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'facile-it/php-openid-client' => array(
            'pretty_version' => '0.2.0',
            'version' => '0.2.0.0',
            'reference' => '8396adf100f32d96f9d943e729eb9608a9e15504',
            'type' => 'library',
            'install_path' => __DIR__ . '/../facile-it/php-openid-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fgrosse/phpasn1' => array(
            'pretty_version' => 'v2.5.0',
            'version' => '2.5.0.0',
            'reference' => '42060ed45344789fb9f21f9f1864fc47b9e3507b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fgrosse/phpasn1',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'firebase/php-jwt' => array(
            'pretty_version' => 'v6.10.0',
            'version' => '6.10.0.0',
            'reference' => 'a49db6f0a5033aef5143295342f1c95521b075ff',
            'type' => 'library',
            'install_path' => __DIR__ . '/../firebase/php-jwt',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '1.9.1',
            'version' => '1.9.1.0',
            'reference' => 'e4490cabc77465aaee90b20cfc9a770f8c04be6b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'http-interop/http-factory-guzzle' => array(
            'pretty_version' => '1.2.0',
            'version' => '1.2.0.0',
            'reference' => '8f06e92b95405216b237521cc64c804dd44c4a81',
            'type' => 'library',
            'install_path' => __DIR__ . '/../http-interop/http-factory-guzzle',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'illuminate/collections' => array(
            'pretty_version' => 'v9.52.16',
            'version' => '9.52.16.0',
            'reference' => 'd3710b0b244bfc62c288c1a87eaa62dd28352d1f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../illuminate/collections',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'illuminate/conditionable' => array(
            'pretty_version' => 'v9.52.16',
            'version' => '9.52.16.0',
            'reference' => 'bea24daa0fa84b7e7b0d5b84f62c71b7e2dc3364',
            'type' => 'library',
            'install_path' => __DIR__ . '/../illuminate/conditionable',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'illuminate/contracts' => array(
            'pretty_version' => 'v9.52.16',
            'version' => '9.52.16.0',
            'reference' => '44f65d723b13823baa02ff69751a5948bde60c22',
            'type' => 'library',
            'install_path' => __DIR__ . '/../illuminate/contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'illuminate/macroable' => array(
            'pretty_version' => 'v9.52.16',
            'version' => '9.52.16.0',
            'reference' => 'e3bfaf6401742a9c6abca61b9b10e998e5b6449a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../illuminate/macroable',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'illuminate/pagination' => array(
            'pretty_version' => 'v9.52.16',
            'version' => '9.52.16.0',
            'reference' => '0c913d6af303ae0060d94d74d68d537637f7e6d4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../illuminate/pagination',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'illuminate/support' => array(
            'pretty_version' => 'v9.52.16',
            'version' => '9.52.16.0',
            'reference' => '223c608dbca27232df6213f776bfe7bdeec24874',
            'type' => 'library',
            'install_path' => __DIR__ . '/../illuminate/support',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ldap-account-manager/ldap-account-manager' => array(
            'pretty_version' => '8.7',
            'version' => '8.7.0.0',
            'reference' => null,
            'type' => 'library',
            'install_path' => __DIR__ . '/../../../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/uri' => array(
            'pretty_version' => '6.7.2',
            'version' => '6.7.2.0',
            'reference' => 'd3b50812dd51f3fbf176344cc2981db03d10fe06',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/uri',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/uri-interfaces' => array(
            'pretty_version' => '2.3.0',
            'version' => '2.3.0.0',
            'reference' => '00e7e2943f76d8cb50c7dfdc2f6dee356e15e383',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/uri-interfaces',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'monolog/monolog' => array(
            'pretty_version' => '2.9.2',
            'version' => '2.9.2.0',
            'reference' => '437cb3628f4cf6042cc10ae97fc2b8472e48ca1f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../monolog/monolog',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'nesbot/carbon' => array(
            'pretty_version' => '2.72.3',
            'version' => '2.72.3.0',
            'reference' => '0c6fd108360c562f6e4fd1dedb8233b423e91c83',
            'type' => 'library',
            'install_path' => __DIR__ . '/../nesbot/carbon',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'paragonie/constant_time_encoding' => array(
            'pretty_version' => 'v2.6.3',
            'version' => '2.6.3.0',
            'reference' => '58c3f47f650c94ec05a151692652a868995d2938',
            'type' => 'library',
            'install_path' => __DIR__ . '/../paragonie/constant_time_encoding',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'paragonie/random_compat' => array(
            'pretty_version' => 'v2.0.21',
            'version' => '2.0.21.0',
            'reference' => '96c132c7f2f7bc3230723b66e89f8f150b29d5ae',
            'type' => 'library',
            'install_path' => __DIR__ . '/../paragonie/random_compat',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/async-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '*',
            ),
        ),
        'php-http/client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '*',
            ),
        ),
        'php-http/discovery' => array(
            'pretty_version' => '1.19.2',
            'version' => '1.19.2.0',
            'reference' => '61e1a1eb69c92741f5896d9e05fb8e9d7e8bb0cb',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../php-http/discovery',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phpmailer/phpmailer' => array(
            'pretty_version' => 'v6.9.1',
            'version' => '6.9.1.0',
            'reference' => '039de174cd9c17a8389754d3b877a2ed22743e18',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpmailer/phpmailer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phpseclib/phpseclib' => array(
            'pretty_version' => '3.0.37',
            'version' => '3.0.37.0',
            'reference' => 'cfa2013d0f68c062055180dd4328cc8b9d1f30b8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpseclib/phpseclib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/clock' => array(
            'pretty_version' => '1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'e41a24703d4560fd0acb709162f73b8adfc3aa0d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/clock',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/clock-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/container' => array(
            'pretty_version' => '2.0.2',
            'version' => '2.0.2.0',
            'reference' => 'c71ecc56dfe541dbd90c5360474fbc405f8d5963',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/container',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client' => array(
            'pretty_version' => '1.0.3',
            'version' => '1.0.3.0',
            'reference' => 'bb5906edc1c324c9a05aa0873d40117941e5fa90',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '*',
                1 => '1.0',
            ),
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.0.2',
            'version' => '1.0.2.0',
            'reference' => 'e616d01114759c4c489f93b099585439f795fe35',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '^1.0',
                1 => '*',
            ),
        ),
        'psr/http-message' => array(
            'pretty_version' => '1.1',
            'version' => '1.1.0.0',
            'reference' => 'cb6ce4845ce34a8ad9e68117c10ee90a29919eba',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
                1 => '*',
            ),
        ),
        'psr/http-server-handler' => array(
            'pretty_version' => '1.0.2',
            'version' => '1.0.2.0',
            'reference' => '84c4fb66179be4caaf8e97bd239203245302e7d4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-server-handler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-server-middleware' => array(
            'pretty_version' => '1.0.2',
            'version' => '1.0.2.0',
            'reference' => 'c1481f747daaa6a0782775cd6a8c26a1bf4a3829',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-server-middleware',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/log' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'reference' => 'd49695b909c3b7628b6289db5479a1c204601f11',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/log-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0.0 || 2.0.0 || 3.0.0',
            ),
        ),
        'psr/simple-cache' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => '408d5eafb83c57f6365a3ca330ff23aa4a5fa39b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/simple-cache',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ramsey/collection' => array(
            'pretty_version' => '1.3.0',
            'version' => '1.3.0.0',
            'reference' => 'ad7475d1c9e70b190ecffc58f2d989416af339b4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ramsey/collection',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ramsey/uuid' => array(
            'pretty_version' => '4.7.5',
            'version' => '4.7.5.0',
            'reference' => '5f0df49ae5ad6efb7afa69e6bfab4e5b1e080d8e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ramsey/uuid',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rhumsaa/uuid' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '4.7.5',
            ),
        ),
        'spomky-labs/base64url' => array(
            'pretty_version' => 'v2.0.4',
            'version' => '2.0.4.0',
            'reference' => '7752ce931ec285da4ed1f4c5aa27e45e097be61d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../spomky-labs/base64url',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'spomky-labs/cbor-php' => array(
            'pretty_version' => 'v2.1.0',
            'version' => '2.1.0.0',
            'reference' => '28e2712cfc0b48fae661a48ffc6896d7abe83684',
            'type' => 'library',
            'install_path' => __DIR__ . '/../spomky-labs/cbor-php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/deprecation-contracts' => array(
            'pretty_version' => 'v3.0.2',
            'version' => '3.0.2.0',
            'reference' => '26954b3d62a6c5fd0ea8a2a00c0353a14978d05c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/deprecation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/http-client' => array(
            'pretty_version' => 'v5.4.37',
            'version' => '5.4.37.0',
            'reference' => '63d93fd99523b9608929a38172da3365a6c0821c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/http-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/http-client-contracts' => array(
            'pretty_version' => 'v2.5.2',
            'version' => '2.5.2.0',
            'reference' => 'ba6a9f0e8f3edd190520ee3b9a958596b6ca2e70',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/http-client-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/http-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '2.4',
            ),
        ),
        'symfony/http-foundation' => array(
            'pretty_version' => 'v6.0.20',
            'version' => '6.0.20.0',
            'reference' => 'e16b2676a4b3b1fa12378a20b29c364feda2a8d6',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/http-foundation',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-mbstring' => array(
            'pretty_version' => 'v1.29.0',
            'version' => '1.29.0.0',
            'reference' => '9773676c8a1bb1f8d4340a62efe641cf76eda7ec',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-mbstring',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php73' => array(
            'pretty_version' => 'v1.29.0',
            'version' => '1.29.0.0',
            'reference' => '21bd091060673a1177ae842c0ef8fe30893114d2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php73',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php80' => array(
            'pretty_version' => 'v1.29.0',
            'version' => '1.29.0.0',
            'reference' => '87b68208d5c1188808dd7839ee1e6c8ec3b02f1b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php80',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php81' => array(
            'pretty_version' => 'v1.29.0',
            'version' => '1.29.0.0',
            'reference' => 'c565ad1e63f30e7477fc40738343c62b40bc672d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php81',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/process' => array(
            'pretty_version' => 'v5.4.36',
            'version' => '5.4.36.0',
            'reference' => '4fdf34004f149cc20b2f51d7d119aa500caad975',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/process',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/psr-http-message-bridge' => array(
            'pretty_version' => 'v2.3.1',
            'version' => '2.3.1.0',
            'reference' => '581ca6067eb62640de5ff08ee1ba6850a0ee472e',
            'type' => 'symfony-bridge',
            'install_path' => __DIR__ . '/../symfony/psr-http-message-bridge',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/service-contracts' => array(
            'pretty_version' => 'v3.0.2',
            'version' => '3.0.2.0',
            'reference' => 'd78d39c1599bd1188b8e26bb341da52c3c6d8a66',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/service-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/translation' => array(
            'pretty_version' => 'v6.0.19',
            'version' => '6.0.19.0',
            'reference' => '9c24b3fdbbe9fb2ef3a6afd8bbaadfd72dad681f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/translation',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/translation-contracts' => array(
            'pretty_version' => 'v3.0.2',
            'version' => '3.0.2.0',
            'reference' => 'acbfbb274e730e5a0236f619b6168d9dedb3e282',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/translation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/translation-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '2.3|3.0',
            ),
        ),
        'thecodingmachine/safe' => array(
            'pretty_version' => 'v1.3.3',
            'version' => '1.3.3.0',
            'reference' => 'a8ab0876305a4cdaef31b2350fcb9811b5608dbc',
            'type' => 'library',
            'install_path' => __DIR__ . '/../thecodingmachine/safe',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'voku/portable-ascii' => array(
            'pretty_version' => '2.0.1',
            'version' => '2.0.1.0',
            'reference' => 'b56450eed252f6801410d810c8e1727224ae0743',
            'type' => 'library',
            'install_path' => __DIR__ . '/../voku/portable-ascii',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-auth/cose-lib' => array(
            'pretty_version' => 'v3.3.12',
            'version' => '3.3.12.0',
            'reference' => 'efa6ec2ba4e840bc1316a493973c9916028afeeb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-auth/cose-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-auth/metadata-service' => array(
            'pretty_version' => 'v3.3.12',
            'version' => '3.3.12.0',
            'reference' => 'ef40d2b7b68c4964247d13fab52e2fa8dbd65246',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-auth/metadata-service',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-auth/webauthn-lib' => array(
            'pretty_version' => 'v3.3.12',
            'version' => '3.3.12.0',
            'reference' => '5ef9b21c8e9f8a817e524ac93290d08a9f065b33',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-auth/webauthn-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-token/jwt-checker' => array(
            'pretty_version' => 'v2.2.11',
            'version' => '2.2.11.0',
            'reference' => '5f31d98155951739e2fae7455e8466ccddd08f50',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-token/jwt-checker',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-token/jwt-core' => array(
            'pretty_version' => 'v2.2.11',
            'version' => '2.2.11.0',
            'reference' => '53beb6f6c1eec4fa93c1c3e5d9e5701e71fa1678',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-token/jwt-core',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-token/jwt-easy' => array(
            'pretty_version' => 'v2.2.11',
            'version' => '2.2.11.0',
            'reference' => '01db23252bb53d4fd36975b55dd58466bab1bb30',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-token/jwt-easy',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-token/jwt-encryption' => array(
            'pretty_version' => 'v2.2.11',
            'version' => '2.2.11.0',
            'reference' => '3b8d67d7c5c013750703e7c27f1001544407bbb2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-token/jwt-encryption',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-token/jwt-key-mgmt' => array(
            'pretty_version' => 'v2.2.11',
            'version' => '2.2.11.0',
            'reference' => '0b116379515700d237b4e5de86879078ccb09d8a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-token/jwt-key-mgmt',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-token/jwt-signature' => array(
            'pretty_version' => 'v2.2.11',
            'version' => '2.2.11.0',
            'reference' => '015b59aaf3b6e8fb9f5bd1338845b7464c7d8103',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-token/jwt-signature',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-token/jwt-signature-algorithm-rsa' => array(
            'pretty_version' => 'v2.2.11',
            'version' => '2.2.11.0',
            'reference' => '513ad90eb5ef1886ff176727a769bda4618141b0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-token/jwt-signature-algorithm-rsa',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'webklex/php-imap' => array(
            'pretty_version' => '5.5.0',
            'version' => '5.5.0.0',
            'reference' => '3c23c8f66b772ce8597772816e068326559e7e4b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../webklex/php-imap',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
